@@ -6,7 +6,7 @@ use Bio::Trace::ABIF;
 use Data::Dumper;
 use File::Basename;
 
-$FASTX::Abi::VERSION = '0.10';
+$FASTX::Abi::VERSION = '0.11';
 
 #ABSTRACT: Read Sanger trace file (chromatograms) in FASTQ format. For traces called with I<hetero> option, the ambiguities will be split into two sequences to allow usage from NGS tools that usually do not understand IUPAC ambiguities.
 
@@ -284,7 +284,7 @@ FASTX::Abi - Read Sanger trace file (chromatograms) in FASTQ format. For traces
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -302,6 +302,20 @@ The source from GitHub is tested using Travis-CI for continuous integration.
 Check also the CPAN grid test for a better estimate of 
 build success using CPAN version of interest. 
 
+=head1 INSTALLATION
+
+Via B<cpanminus>:
+
+    # Install cpanminus if you don't have it:
+    curl -L https://cpanmin.us | perl - --sudo App::cpanminus
+
+    # Install FASTX::Abi
+    cpanm FASTX::Abi
+
+Via Miniconda L<https://docs.conda.io/en/latest/miniconda.html>:
+
+    conda install -y -c bioconda perl-fastx-abi
+
 =head1 HETERO CALLING (IUPAC AMBIGUITIES)
 
 When Sanger-sequencing a mix of molecules (i.e. PCR product from heterozigous genome) containing a single-base polimorphisms,
